@@ -203,7 +203,7 @@ def asyncTimeout(waitSeconds: float):
     def _log(func: Any):
         @wraps(func)
         async def wrapper(*args: Any, **kwargs: Any):
-            with timeout(waitSeconds):
+            async with timeout(waitSeconds):
                 return await func(*args, **kwargs)
         return wrapper
     return _log
