@@ -73,17 +73,18 @@ def _runTaskFile(file: str):
         endIndex = fileContent.index(findStr, startIndex + 1)
         content = fileContent[startIndex + len(findStr):endIndex].strip().replace("\r\n", "\n")
         lineAry = content.split("\n")
-        lineAry = [x[2:].strip() for x in lineAry]
+        lineAry = [x[3:].strip() for x in lineAry]
         for line in lineAry:
-            sepIndex = line.find(" ")
-            parDict: dict[str, Any] = {}
-            if sepIndex > -1:
-                moduleName = line[:sepIndex].strip()
-                parDict = eval(line[sepIndex:])
-                assert type(parDict) == dict, f"参数无法解析成字典类型 line={line}"
-            else:
-                moduleName = line
-            taskList.append((moduleName, parDict))
+            if line:
+                sepIndex = line.find(" ")
+                parDict: dict[str, Any] = {}
+                if sepIndex > -1:
+                    moduleName = line[:sepIndex].strip()
+                    parDict = eval(line[sepIndex:])
+                    assert type(parDict) == dict, f"参数无法解析成字典类型 line={line}"
+                else:
+                    moduleName = line
+                taskList.append((moduleName, parDict))
         assert len(taskList) > 0
         os.system(f"title {getFileBaseName(file)}")
     except:
@@ -158,6 +159,6 @@ def _runTaskList(taskList: list[TaskDataType]):
         if lockFile:
             remove(lockFile)
 
-        if not isTaskByDev():
+        if not isTaskByDev() and (not sys.executable.endswith('python3')):  # 苹果电脑上用的是python3，不要休眠直接退出
             while True:
                 time.sleep(1)
