@@ -2,7 +2,7 @@ import os
 from typing import Callable
 from zipfile import ZIP_DEFLATED, ZipFile
 
-from . import getAllFileAndFolderList, makeFolder
+from beniutils import getAllFileAndFolderList, makeFolder
 
 
 def zipFile(toFile: str, fileFolderOrAry: str | list[str], rename: Callable[[str], str] | None = None):
